Skip to contents

anndata reference dataset

Usage

AML_h5ad()

Format

An AnnDataR6 object with 659 features and 250 cells. Included experiments:

RNA (main experiment)

mRNA expression data for 462 genes used as markers for hematopoietic stem and progenitor (HSPC) cell types at varying stages of differentiation.

AB

Surface protein expression data for 197 surface protein markers associated with HSPCs.

Details

The function described here is used to load the AnnData R6 object, it should be called as a function.